##  Restricting Multiple Subscriptions from the Same User to a Fact Sheet
By default, a user can subscribe to a fact sheet multiple times under different subscription roles. However, admins can control whether users are allowed to have multiple subscriptions for a single fact sheet. You can restrict to allow only one subscription per user for a fact sheet. To implement this restriction, follow these steps:
  1. In the administration area, select General.
  2. Under Multiple Subscriptions, select Disabled from the drop-down menu.
  3. Click Save to apply the change.
